@@ -1,4 +1,5 @@
 # (C) Copyright 2015,2017 Hewlett Packard Enterprise Development LP
+# (C) Copyright 2017 KylinCloud
 
 import base64
 import logging
@@ -14,6 +15,9 @@ log = logging.getLogger(__name__)
 
 DEFAULT_TIMEOUT = 20
 
+from keystoneclient.v2_0 import client as kc
+from monasca_agent.common import keystone
+
 
 def add_basic_auth(request, username, password):
     """A helper to add basic authentication to a urllib2 request.
@@ -26,17 +30,11 @@ def add_basic_auth(request, username, password):
 
 
 def get_keystone_client(config):
-    import keystoneclient.v2_0.client as kc
-    kwargs = {
-        'username': config.get('admin_user'),
-        'project_name': config.get('admin_tenant_name'),
-        'password': config.get('admin_password'),
-        'auth_url': config.get('identity_uri'),
-        'endpoint_type': 'internalURL',
-        'region_name': config.get('region_name'),
-    }
+    session = keystone.get_session(config)
 
-    return kc.Client(**kwargs)
+    return kc.Client(session=session,
+                     endpoint_type=config.get('endpoint_type', 'publicURL'),
+                     region_name=config.get('region_name'))
 
 
 def get_tenant_name(tenants, tenant_id):
@@ -110,7 +108,7 @@ class KubernetesConnector(object):
         """Set kubernetes API string from default container environment
         variables
         """
-        api_host = os.environ.get('KUBERNETES_SERVICE_HOST', "kubernetes")
+        api_host = os.environ.get('KUBERNETES_SERVICE_HOST', "kubernetes.default")
         api_port = os.environ.get('KUBERNETES_SERVICE_PORT', "443")
         self.api_url = "https://{}:{}".format(api_host, api_port)
 
