@@ -1,6 +1,6 @@
 #
 # Copyright 2012 Red Hat, Inc
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,6 +15,8 @@
 # under the License.
 """Implementation of Inspector abstraction for libvirt."""
 
+import logging
+
 from lxml import etree
 from oslo_config import cfg
 from oslo_utils import units
@@ -24,6 +26,8 @@ from monasca_agent.collector.virt import inspector as virt_inspector
 
 libvirt = None
 
+log = logging.getLogger(__name__)
+
 
 OPTS = [
     cfg.StrOpt('libvirt_type',
@@ -196,17 +200,23 @@ class LibvirtInspector(virt_inspector.Inspector):
         domain = self._get_domain_not_shut_off_or_raise(instance)
 
         tree = etree.fromstring(domain.XMLDesc(0))
-        for device in filter(
-                bool,
-                [target.get("dev")
-                 for target in tree.findall('devices/disk/target')]):
-            disk = virt_inspector.Disk(device=device)
-            block_info = domain.blockInfo(device)
-            info = virt_inspector.DiskInfo(capacity=block_info[0],
-                                           allocation=block_info[1],
-                                           physical=block_info[2])
-
-            yield (disk, info)
+        for disk in tree.findall('devices/disk'):
+            disk_type = disk.get('type')
+            if disk_type:
+                if disk_type == 'network':
+                    log.debug('Inspection disk usage of network disk '
+                              '%(instance_uuid)s unsupported by libvirt' % {
+                                  'instance_uuid': instance.id})
+                    continue
+                target = disk.find('target')
+                device = target.get('dev')
+                if device:
+                    dsk = virt_inspector.Disk(device=device)
+                    block_info = domain.blockInfo(device)
+                    info = virt_inspector.DiskInfo(capacity=block_info[0],
+                                                   allocation=block_info[1],
+                                                   physical=block_info[2])
+                    yield (dsk, info)
 
     def inspect_memory_resident(self, instance, duration=None):
         domain = self._get_domain_not_shut_off_or_raise(instance)
