@@ -1,6 +1,5 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
 # Copyright 2016 FUJITSU LIMITED
-# Copyright 2017 SUSE Linux GmbH
 
 """Classes for monitoring the monitoring server stack.
 
@@ -14,12 +13,10 @@ import yaml
 
 from six.moves import configparser
 
-from monasca_agent.common.psutil_wrapper import psutil
 import monasca_setup.agent_config
 import monasca_setup.detection
 from monasca_setup.detection import find_process_cmdline
 from monasca_setup.detection import find_process_name
-from monasca_setup.detection.utils import get_agent_username
 from monasca_setup.detection.utils import watch_process
 from monasca_setup.detection.utils import watch_process_by_username
 
@@ -74,8 +71,8 @@ class MonAgent(monasca_setup.detection.Plugin):
     def build_config(self):
         """Build the config as a Plugins object and return."""
         log.info("\tEnabling the Monasca Agent process check")
-        return watch_process_by_username(get_agent_username(), 'monasca-agent',
-                                         'monitoring', 'monasca-agent')
+        return watch_process_by_username('mon-agent', 'monasca-agent', 'monitoring',
+                                         'monasca-agent')
 
     def dependencies_installed(self):
         return True
@@ -117,10 +114,7 @@ class MonAPI(monasca_setup.detection.Plugin):
             p_exe = process.as_dict(['exe'])['exe']
             for m in _APACHE_MARKERS:
                 if m in p_exe:
-                    if psutil.version_info < (2, 0):
-                        return process.parent
-                    else:
-                        return process.parent()
+                    return process.parent()
             return None
 
         api_process = find_process_cmdline('monasca-api')
@@ -199,10 +193,8 @@ class MonNotification(monasca_setup.detection.Plugin):
     def build_config(self):
         """Build the config as a Plugins object and return."""
         log.info("\tEnabling the Monasca Notification healthcheck")
-        notification_process = find_process_cmdline('monasca-notification')
-        notification_user = notification_process.as_dict(['username'])['username']
-        return watch_process_by_username(notification_user, 'monasca-notification',
-                                         'monitoring', 'monasca-notification')
+        return watch_process_by_username('mon-notification', 'monasca-notification', 'monitoring',
+                                         'monasca-notification')
 
     def dependencies_installed(self):
         return True
@@ -329,26 +321,6 @@ def dropwizard_metrics(service, component, url, whitelist):
     return config
 
 
-class MonInfluxDB(monasca_setup.detection.Plugin):
-    """Detect InfluxDB and setup some simple checks."""
-
-    def _detect(self):
-        """Run detection, set self.available True if the service is detected.
-        """
-
-        if find_process_name('influxd') is not None:
-            self.available = True
-
-    def build_config(self):
-        """Build the config as a Plugins object and return."""
-        log.info("\tEnabling the Monasca InfluxDB check")
-        return watch_process(['influxd'], 'monitoring', 'influxd',
-                             exact_match=False)
-
-    def dependencies_installed(self):
-        return True
-
-
 class _DropwizardJavaHelper(object):
     """Mixing to locate configuration file for DropWizard app
 
